@@ -7,6 +7,7 @@ import os
 import platform
 import re
 import socket
+import subprocess
 
 MAC_ADDR_PREFIX = [
     "B8:27:EB",
@@ -33,8 +34,9 @@ def ping(ip):
 
     prefix = ip.rsplit(".", maxsplit=1)[0]
 
-    for x in range(0x1, 0xff):
-        os.popen(f"ping {prefix}.{x}")
+    with open(os.devnull, mode="w") as devnull:
+        for x in range(0x1, 0xff):
+            subprocess.Popen(f"ping {prefix}.{x}", shell=True, stdout=devnull)
 
 
 def get_raspberry_pi():
@@ -68,6 +70,3 @@ def get_raspberry_pi():
         }
         devices.append(device)
     return devices
-
-
-ping(get_cur_ip())
\ No newline at end of file
